/* 
 *
 * $Id: k3bexternalbinoptiontab.h 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This file is part of the K3b project.
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */


#ifndef K3B_EXTERNALBIN_OPTIONTAB_H
#define K3B_EXTERNALBIN_OPTIONTAB_H

#include <tqwidget.h>



class TQPushButton;
class TQListViewItem;
class TDEListView;
class K3bExternalBinManager;
class K3bExternalBinWidget;


class K3bExternalBinOptionTab : public TQWidget
{
Q_OBJECT
  

 public:
  K3bExternalBinOptionTab( K3bExternalBinManager*, TQWidget*, const char* name = 0 );
  ~K3bExternalBinOptionTab();

  void readSettings();
  void saveSettings();

 private:
  K3bExternalBinManager* m_manager;

  K3bExternalBinWidget* m_externalBinWidget;
};



#endif
